package com.sample.android.android_beam_1;

import java.nio.charset.Charset;
import java.util.Date;

import android.app.Activity;
import android.os.Bundle;
import android.view.Window;
import android.content.Intent;
import android.graphics.Color;
import android.graphics.Typeface;
import android.nfc.NdefMessage;
import android.nfc.NdefRecord;
import android.nfc.NfcAdapter;
import android.nfc.NfcAdapter.CreateNdefMessageCallback;
import android.nfc.NfcEvent;
import android.os.Parcelable;

import android.view.Gravity;
import android.view.ViewGroup;
import android.widget.LinearLayout;
import android.widget.TextView;
import android.widget.Toast;

public class Android_Beam_1 extends Activity implements CreateNdefMessageCallback{
    /** Called when the activity is first created. */

	private final int WC = ViewGroup.LayoutParams.WRAP_CONTENT;
	private LinearLayout layout;

	private NfcAdapter nfc_adapter;
	private Intent intent;

	private TextView textview1;
	private String beam_text = "";

    @Override
    public void onCreate(Bundle savedInstanceState)
    {
        super.onCreate(savedInstanceState);
        requestWindowFeature(Window.FEATURE_NO_TITLE);  //タイトルの非表示

        layout = new LinearLayout(this);
        layout.setOrientation(LinearLayout.VERTICAL);
        layout.setBackgroundColor(Color.rgb(0,0,255));  //背景「青」
        layout.setGravity(Gravity.CENTER);  //中央寄せ
        setContentView(layout);

        textview1 = new TextView(this);
        textview1.setTextColor(Color.WHITE);  //文字の色「白」
        textview1.setTextSize(20);
        textview1.setTypeface(Typeface.create(Typeface.SERIF, Typeface.BOLD_ITALIC));
        textview1.setText("Android Beam の表示！");
        layout.addView(textview1, new LinearLayout.LayoutParams(WC, WC));

        //Android Beamの準備
        nfc_adapter = NfcAdapter.getDefaultAdapter(this);

        if(nfc_adapter != null)
    	{
            nfc_adapter.setNdefPushMessageCallback(this,this);
            //nfc_adapter.setOnNdefPushCompleteCallback(this,this);
        }else
        {
            Toast.makeText(this, "NFCを利用できない端末です !", Toast.LENGTH_LONG).show();
            //finish();  //Activityの終了！：エミュレータのときは、何も表示されないのでコメントにする
            return;
        }
    }

    //Android Beam が可能な別端末が範囲内にある時に呼ばれる
    public NdefMessage createNdefMessage(NfcEvent event)
    {
        //送信するメッセージ用のテキストの設定
        //beam_text = textview1.getText().toString();  //参考
    	beam_text = "受信：" + "Hello Robert ! [" + (new Date()) + " ]";

    	//AndroidBeam で送信するメッセージの生成
        NdefMessage send_msg = new NdefMessage( new NdefRecord[]{
                //MIMEタイプを含んだレコードの生成
                createMimeRecord("application/com.sample.android.android_beam_1",beam_text.getBytes()),

                //AARを含んだレコードの生成
                NdefRecord.createApplicationRecord("com.sample.android.android_beam_1")
            });

        return send_msg;
    }

    //AARを含んだMIME Typeのレコードの生成
    public NdefRecord createMimeRecord(String mimeType,byte[] payload)
    {
        byte[] mime_bytes = mimeType.getBytes(Charset.forName("US-ASCII"));

        NdefRecord mime_record = new NdefRecord(NdefRecord.TNF_MIME_MEDIA, mime_bytes,new byte[0],payload);

        return mime_record;
    }

    //インテントを受信したときに呼ばれる
    @Override
    public void onNewIntent(Intent intent)
    {
        setIntent(intent);  //受信したインテントをセット
    }

    //ユーザのディスプレイのタッチ操作の受付を開始したときに呼ばれる
    @Override
    public void onResume()
    {
        super.onResume();

        intent = getIntent();

        //Android Beam の受信処理
        if(NfcAdapter.ACTION_NDEF_DISCOVERED.equals(intent.getAction()))
    	{
        	//Intentに含まれるメッセージを取り込む
            Parcelable[] raw_msgs = intent.getParcelableArrayExtra( NfcAdapter.EXTRA_NDEF_MESSAGES);

            if (raw_msgs != null)
            {
               NdefMessage msg = (NdefMessage)raw_msgs[0];  //1個のメッセージがAndroid Beamで送信されたとき

               textview1.setText(new String(msg.getRecords()[0].getPayload()));  //record[0]=MIME type, record[1]=AAR
            }
        }
    }
}