package com.sample.android.camera_main1;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.io.*;

import android.content.Context;
import android.hardware.Camera;
import android.hardware.Camera.PictureCallback;
import android.hardware.Camera.ShutterCallback;
import android.view.SurfaceHolder;
import android.view.SurfaceView;
import android.widget.Toast;
import android.view.MotionEvent;
import android.widget.Toast;

public class Camera_Preview1 extends SurfaceView implements SurfaceHolder.Callback ,Camera.PictureCallback{

	private SurfaceHolder s_holder;
	private Camera camera;

	private static final String SDCARD_FOLDER = "sdcard/My_Travel";
	
	// TODO 自動生成されたコンストラクター//
	public Camera_Preview1(Context context)
	{
		super(context);

		s_holder = getHolder(); //サーフェスホルダーの生成

		//SurfaceHolderで表示の更新などがされると、コールバック設定されたインスタンスのメソッドが呼び出されるようになる
		s_holder.addCallback(this); //コールバックを組み込む(登録する)

        //SurfaceViewのタイプをノーマルからPUSHバッファに変更
		s_holder.setType(SurfaceHolder.SURFACE_TYPE_PUSH_BUFFERS); // プッシュバッファの指定
	}

	//① Syrafce が生成されたときのイベントの処理(SurfaceViewが生成されたらカメラをオープンする)
	public void surfaceCreated(SurfaceHolder holder)
	{
	    if(camera == null)
	    {
	       try{
	    	    camera = Camera.open(); //カメラをオープン
	            camera.setPreviewDisplay(holder); //プレビューディスプレイを設定
	       }
	       catch(IOException e)
	       {
                camera.release(); //カメラをリリース
                camera = null;
                Toast.makeText(getContext(), "サポートしていない言語です！",Toast.LENGTH_LONG).show();
           }
         }
    }

	//② Surface が変更のときのイベントの処理
	public void surfaceChanged(SurfaceHolder holder, int format, int width, int height)
	{
        Camera.Parameters parameter = camera.getParameters(); //カメラパラメータを取得
         //parameter.setPreviewFormat(format); //プレビューのフォーマットを設定
         //parameter.setPictureSize(800, 600); // WVGA Size
         //parameter.setPictureSize(width*2, height*2);  //プレビューサイズの2倍の大きさで画像を保存する
	    camera.setParameters(parameter); //カメラにパラメータを設定
	    camera.startPreview(); //プレビューを再開
	}

	//③ Surface が解放されたときのイベントの処理(SurfaceViewが破棄されたらカメラを解放する)
	public void surfaceDestroyed(SurfaceHolder holder)
	{
		camera.setPreviewCallback(null);  //Callback関数を停止
	    camera.stopPreview(); //カメラのプレビューを停止
	    camera.release(); //カメラをリリース
	    camera = null;
	}

    //画面のタッチして撮影を開始する
    public boolean onTouchEvent(MotionEvent event)
    {
        if( event.getAction() == MotionEvent.ACTION_DOWN ) //画面をタッチした時！
        {
        	// 撮影を行う(カメラのスクリーンショットの取得)
        	camera.takePicture(Shutter_Listener , null, this); //撮影コールバック関数 onPictureTaken() を呼ぶ
         }
         return true;
    }

    private Camera.ShutterCallback Shutter_Listener =  new Camera.ShutterCallback()
    {  
        public void onShutter()
        {  
	         Toast.makeText(getContext(), "シャッターON !",Toast.LENGTH_LONG).show();
        }  
    };  
    
    //撮影を行う
    public void onPictureTaken(byte[] data, Camera camera) //撮影コールバック関数
    {
    	//撮影日の連番数値をファイル名に使用するとき
    	String date1 = new SimpleDateFormat("yyyyMMdd_hh_mmss").format(new Date()); //201100814

        try {
                String file_Name = "pict_" + date1 + ".jpg";

                File dir_obj = new File(SDCARD_FOLDER );  //作成するFolder名「"sdcard/My_Travel"」を指定

                if (!dir_obj.exists())
                {
                    dir_obj.mkdirs();  //撮影した画像を保存するフォルダ「"sdcard/My_Travel"」の作成(make folders)
                }

                //SDカードの指定のFolder にJPEGデータを保存する
                if (data != null)
                {
                    FileOutputStream file_output_stream = null;

                    try {
                    	  //IS03では、『/sdcard/』ではなく、『/mnt/sdcard/』
                          file_output_stream = new FileOutputStream(SDCARD_FOLDER  + file_Name);

                          file_output_stream.write(data); //データの書き込み
                          file_output_stream.close();

                    }catch (IOException e)
                    {
                          file_output_stream.close();
                          camera.stopPreview();
                          camera.release();
                          camera = null;
                          Toast.makeText(getContext(), e.toString(),Toast.LENGTH_LONG).show();
                    }
                }

        } catch (Exception e)
        {
                camera.setPreviewCallback(null);
                camera.stopPreview();
                camera.release();
                camera = null;
                Toast.makeText(getContext(), e.toString(),Toast.LENGTH_LONG).show();
        }

        camera.startPreview(); // プレビューを再スタート
   }
}
