package com.sample.android.sensor_test3;

import java.util.List;

import android.app.Activity;
import android.os.Bundle;
import android.os.Handler;
import android.os.Message;
import android.content.Context;
import android.graphics.Color;
import android.graphics.Typeface;
import android.hardware.Sensor;
import android.hardware.SensorEvent;
import android.hardware.SensorEventListener;
import android.hardware.SensorManager;
import android.util.Log;
import android.view.View;
import android.view.Gravity;
import android.view.ViewGroup;
import android.widget.Button;
import android.view.View.OnClickListener;
import android.widget.LinearLayout;
import android.widget.TextView;
import android.widget.Toast;

public class Sensor_test3 extends Activity implements OnClickListener,SensorEventListener{
    /** Called when the activity is first created. */
	
	private final int WC = ViewGroup.LayoutParams.WRAP_CONTENT;

	private LinearLayout layout;

	private TextView text1;
	private Button   button;

	private boolean       registered_Sensor; //リスナーの登録用
    private SensorManager sensor_manager; //センサーマネージャ
    private Sensor        orientation;    //傾きせンサー
    private Sensor        accelerometer;  //加速度せンサー
    private Sensor_Display_Handler sensor_handler;    //定期処理ハンドラのクラス

    private float azimuth;  //方位角
    private float pitch;    //縦揺れ
    private float roll;     //横揺れ
    private float x_axis;   //X軸加速度
    private float y_axis;   //Y軸加速度
    private float z_axis;   //Z軸加速度

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);

        layout = new LinearLayout(this);

        layout.setBackgroundColor(Color.rgb(0,0,0));
        layout.setOrientation(LinearLayout.VERTICAL);
        layout.setGravity(Gravity.CENTER);  //中央寄せ
        setContentView(layout);

        text1 = new TextView(this);
        text1.setTextColor(Color.RED);
        text1.setTextSize(20);
        text1.setTypeface(Typeface.create(Typeface.SERIF, Typeface.BOLD_ITALIC));
        text1.setText("傾きと加速度の表示\n");
        layout.addView(text1, new LinearLayout.LayoutParams(WC, WC));
        
        button = new Button(this);  //Startボタンの生成
        button.setTextColor(Color.RED);
        button.setTextSize(18);
        button.setTypeface(Typeface.create(Typeface.SERIF, Typeface.BOLD_ITALIC));
        button.setText("Start");
        button.setOnClickListener(this);
        button.setGravity(Gravity.CENTER);
        layout.addView(button, new LinearLayout.LayoutParams(WC, WC));

        //センサーマネージャの取得
        sensor_manager = (SensorManager)getSystemService(Context.SENSOR_SERVICE);
    }

    //アプリの再開 リスナーの登録と解除は、対で行う必要があります。
    protected void onResume()
    {
        super.onResume();

            List<Sensor> sensor_list;

            //傾きセンサーを取得
            sensor_list = sensor_manager.getSensorList(Sensor.TYPE_ORIENTATION);

            if(sensor_list.size() > 0)
            {
            	//傾きセンサーを取得
                orientation = sensor_list.get(0);
                Toast.makeText(getApplicationContext(), "傾きセンサーを取得！",Toast.LENGTH_SHORT).show();
                
                //傾きセンサーにリスナーを登録  第3引数で感度を指定できます。
                registered_Sensor = sensor_manager.registerListener(this, orientation, SensorManager.SENSOR_DELAY_FASTEST);
            }else{
            	Toast.makeText(getApplicationContext(), "傾きセンサー NO ！",Toast.LENGTH_SHORT).show();
            	return;
            }

            //加速度センサーを取得
            sensor_list = sensor_manager.getSensorList(Sensor.TYPE_ACCELEROMETER);

            if(sensor_list.size() > 0)
            {
            	//加速度センサーを取得
            	accelerometer = sensor_list.get(0);

                //加速度センサーにリスナーを登録
            	registered_Sensor = sensor_manager.registerListener(this, accelerometer, SensorManager.SENSOR_DELAY_FASTEST);
            }else{
            	Toast.makeText(getApplicationContext(), "加速度センサー NO ！",Toast.LENGTH_SHORT).show();
            	return;
            }

            Toast.makeText(getApplicationContext(), "onResume！",Toast.LENGTH_SHORT).show();
    }

    //Startボタンのクリック //Sensor_Display_Handler sensor_handler
    public void onClick(View v)
    {
        if (v == button)
        {
            //定期処理の開始
        	sensor_handler = new Sensor_Display_Handler();  //Sensor_Display_Handlerクラス作成用
        	sensor_handler.sleep(0);
        }
    }

    //定期処理のハンドラクラス
    public class Sensor_Display_Handler extends Handler
    {
        //ハンドルメッセージ
        public void handleMessage(Message msg)
        {
            msg_Disp();  //センサーのデータを表示する自作のメソッド
        }

        //スリープ
        public void sleep(long delayMills)
        {
            removeMessages(0);
            sendMessageDelayed(obtainMessage(0),delayMills);
        }
    }

    //定期的な処理
    public void msg_Disp()
    {
        text1.setText(
                "\nZ-軸 方向の方位   : "   + azimuth +
                "\nX-軸 方向のピッチ : "   + pitch   +
                "\nY-軸 方向のロール : "   + roll    +
                "\n\nX-軸 方向の加速度 : " + x_axis  +
                "\nY-軸 方向の加速度 : "   + y_axis  +
                "\nZ-軸 方向の加速度 : "   + z_axis  + "\n"
        );

        if (sensor_handler !=null ){ sensor_handler.sleep(100); }
    }
    
    //センサーの値が変化したら呼び出される
    public void onSensorChanged(SensorEvent event)
    {
    	//Toast.makeText(getApplicationContext(), "onSensorChanged！",Toast.LENGTH_SHORT).show();

    	 //傾きの取得
    	 //i(event.sensor == orientation)  //参考
         if(event.sensor.getType() == Sensor.TYPE_ORIENTATION)
         {
             azimuth = event.values[0];
             pitch   = event.values[1];
             roll    = event.values[2];
          }

          //加速度の取得
          //if(event.sensor == accelerometer)  //参考
          if(event.sensor.getType() == Sensor.TYPE_ACCELEROMETER)
          {
              x_axis = event.values[3];
              y_axis = event.values[4];
              z_axis = event.values[5];
          }
    }

    //精度が変わったときに呼ばれる
    public void onAccuracyChanged(Sensor sensor, int accuracy)
    {
    	//特に処理をしない！
    }
    
    //アプリの一時停止 アプリ終了時に必ずonPauseを通るため
    protected void onPause()
    {
    	super.onPause();

        if(registered_Sensor)
        {
        	//リスナーを解除
            sensor_manager.unregisterListener(this);
            registered_Sensor = false;

            sensor_handler = null;
        }
    }
}
        